==> sca-patterns-sle15-1.5.5.tar.gz: sca-patterns-sle15-1.5.5/patterns/SLE/sle15sp0/kgraft-patch_SUSE-SU-2020_1789-1_15.0.ltss.py <==
#!/usr/bin/python3
#
# Title:       Important Security Announcement for kgraft-patch SUSE-SU-2020:1789-1
# Description: Security fixes for SUSE Linux Kernel Live Patch 15 SP0 LTSS
# Source:      Security Announcement Parser v1.5.2
# Modified:    2020 Nov 16
#
##############################################################################
# Copyright (C) 2020 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record (jason.record@suse.com)
#
##############################################################################

import os
import Core
import SUSE

META_CLASS = "Security"
META_CATEGORY = "SLE"
META_COMPONENT = "kgraft-patch"
PATTERN_ID = os.path.basename(__file__)
PRIMARY_LINK = "META_LINK_Security"
OVERALL = Core.TEMP
OVERALL_INFO = "NOT SET"
OTHER_LINKS = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2020-June/007045.html"
Core.init(META_CLASS, META_CATEGORY, META_COMPONENT, PATTERN_ID, PRIMARY_LINK, OVERALL, OVERALL_INFO, OTHER_LINKS)

LTSS = True
NAME = 'kgraft-patch'
MAIN = ''
SEVERITY = 'Important'
TAG = 'SUSE-SU-2020:1789-1'
PACKAGES = {}
SERVER = SUSE.getHostInfo()

if ( SERVER['DistroVersion'] == 15):
	if ( SERVER['DistroPatchLevel'] == 0 ):
		PACKAGES = {
			'tomcat': '9.0.35-3.57.3',
			'tomcat-admin-webapps': '9.0.35-3.57.3',
			'tomcat-el-3_0-api': '9.0.35-3.57.3',
			'tomcat-jsp-2_3-api': '9.0.35-3.57.3',
			'tomcat-lib': '9.0.35-3.57.3',
			'tomcat-servlet-4_0-api': '9.0.35-3.57.3',
			'tomcat-webapps': '9.0.35-3.57.3',
		}
		SUSE.securityAnnouncementPackageCheck(NAME, MAIN, LTSS, SEVERITY, TAG, PACKAGES)
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the service pack scope")
else:
	Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the distribution scope")
Core.printPatternResults()

==> sca-patterns-sle15-1.5.8.tar.gz: sca-patterns-sle15-1.5.8/patterns/SLE/sle15sp0/kgraft-patch_SUSE-SU-2020_3375-1_15.0.ltss.py <==
#!/usr/bin/python3
#
# Title:       Moderate Security Announcement for kgraft-patch SUSE-SU-2020:3375-1
# Description: Security fixes for SUSE Linux Kernel Live Patch 15 SP0 LTSS
# Source:      Security Announcement Parser v1.5.2
# Modified:    2020 Dec 10
#
##############################################################################
# Copyright (C) 2020 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record (jason.record@suse.com)
#
##############################################################################

import os
import Core
import SUSE

META_CLASS = "Security"
META_CATEGORY = "SLE"
META_COMPONENT = "kgraft-patch"
PATTERN_ID = os.path.basename(__file__)
PRIMARY_LINK = "META_LINK_Security"
OVERALL = Core.TEMP
OVERALL_INFO = "NOT SET"
OTHER_LINKS = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2020-November/007801.html"
Core.init(META_CLASS, META_CATEGORY, META_COMPONENT, PATTERN_ID, PRIMARY_LINK, OVERALL, OVERALL_INFO, OTHER_LINKS)

LTSS = True
NAME = 'kgraft-patch'
MAIN = ''
SEVERITY = 'Moderate'
TAG = 'SUSE-SU-2020:3375-1'
PACKAGES = {}
SERVER = SUSE.getHostInfo()

if ( SERVER['DistroVersion'] == 15):
	if ( SERVER['DistroPatchLevel'] == 0 ):
		PACKAGES = {
			'krb5': '1.15.2-6.12.2',
			'krb5-32bit': '1.15.2-6.12.2',
			'krb5-32bit-debuginfo': '1.15.2-6.12.2',
			'krb5-client': '1.15.2-6.12.2',
			'krb5-client-debuginfo': '1.15.2-6.12.2',
			'krb5-debuginfo': '1.15.2-6.12.2',
			'krb5-debugsource': '1.15.2-6.12.2',
			'krb5-devel': '1.15.2-6.12.2',
			'krb5-plugin-kdb-ldap': '1.15.2-6.12.2',
			'krb5-plugin-kdb-ldap-debuginfo': '1.15.2-6.12.2',
			'krb5-plugin-preauth-otp': '1.15.2-6.12.2',
			'krb5-plugin-preauth-otp-debuginfo': '1.15.2-6.12.2',
			'krb5-plugin-preauth-pkinit': '1.15.2-6.12.2',
			'krb5-plugin-preauth-pkinit-debuginfo': '1.15.2-6.12.2',
			'krb5-server': '1.15.2-6.12.2',
			'krb5-server-debuginfo': '1.15.2-6.12.2',
		}
		SUSE.securityAnnouncementPackageCheck(NAME, MAIN, LTSS, SEVERITY, TAG, PACKAGES)
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the service pack scope")
else:
	Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the distribution scope")
Core.printPatternResults()
